# Arkindex Frontend

## Dev Setup

1. Install Node.js 12 or later and NPM
2. Clone the repository
3. `npm install`
4. `pip install pre-commit`
5. `pre-commit install`

## Common operations

* `npm run build`: Build for development, no Docker image
* `npm start`: Start a local development server on `localhost:8080`
* `npm run production`: Build for production, no Docker image
* `npm run test` or `npm t`: Run unit tests

* `make build`: Build to a local Docker image using latest GitLab CI artifact
* `make clean`: Clean build stuff
* `make all`: Clean and build

## Linting rules

See the `.eslintrc.yml` file for the exact ESLint settings. The linting rules are based on the following sets:

* [StandardJS](https://standardjs.com/)
* [ESLint Recommended](https://eslint.org/docs/rules/)
* [Vue.js Essential + Strongly Recommended](https://eslint.vuejs.org/rules/)
* [`eslint-plugin-import`](https://www.npmjs.com/package/eslint-plugin-import)

Some rules have been customized:

* Using `==` and `!=` in templates will show warnings &mdash; use `===` and `!==` instead ([vue/eqeqeq](https://eslint.vuejs.org/rules/eqeqeq.html));
* Using `this` in a template causes errors &mdash; use `text` instead of `this.text` ([vue/this-in-template](https://eslint.vuejs.org/rules/this-in-template.html));
* Single-line HTML elements are allowed to hold content (`<h1>hello</h1>` is allowed);
* To bind JavaScript expressions to attributes, use `:property=""`, not `v-bind:property=""`, but to bind JavaScript expressions to events, use `v-on:event=""`, not `@event=""` ([vue/v-bind-style](https://eslint.vuejs.org/rules/v-bind-style.html), [vue/v-on-style](https://eslint.vuejs.org/rules/v-on-style.html))
* Single-line HTML elements can have up to three attributes ; you have to switch to multiline elements with one attribute per line above that ([vue/max-attributes-per-line](https://eslint.vuejs.org/rules/max-attributes-per-line.html))
* Void elements (HTML elements which do not hold content, like `br`) should be self-closing &mdash; `<br />` instead of `<br>` ([vue/html-self-closing](https://eslint.vuejs.org/rules/html-self-closing.html))
* HTML elements that can hold content like `p` should never be self-closing &mdash; `<p></p>` instead of `<p />` ([vue/html-self-closing](https://eslint.vuejs.org/rules/html-self-closing.html))
* StandardJS-like linting is now applied on all JS code inside `<template>` (linting was only done on the HTML, not the JS bits)
* Component names must match their file names ([vue/match-component-file-name](https://eslint.vuejs.org/rules/match-component-file-name.html))
* Component names must use PascalCase ([vue/component-definition-name-casing](https://eslint.vuejs.org/rules/component-definition-name-casing.html) and [vue/component-name-in-template-casing](https://eslint.vuejs.org/rules/component-name-in-template-casing.html))
* Components cannot be named after existing HTML or SVG tags ([vue/no-reserved-component-names](https://eslint.vuejs.org/rules/no-reserved-component-names.html))
* The `slot`, `scope` and `slot-scope` attributes are deprecated since Vue.js 2.6.0+ and linting rules forbid them ([vue/no-deprecated-scope-attribute](https://eslint.vuejs.org/rules/no-deprecated-scope-attribute.html), [vue/no-deprecated-slot-attribute](https://eslint.vuejs.org/rules/no-deprecated-slot-attribute.html), [vue/no-deprecated-slot-scope-attribute](https://eslint.vuejs.org/rules/no-deprecated-slot-scope-attribute.html))
* Use the long form `v-slot:default="..."` instead of `#default="..."` to be more explicit ([vue/v-slot-style](https://eslint.vuejs.org/rules/v-slot-style.html))
* Static `style` attributes that can be replaced by CSS classes are forbidden—use CSS classes instead ([vue/no-static-inline-styles](https://eslint.vuejs.org/rules/no-static-inline-styles.html))
* `<template>`, `<script>` and `<style>` must be separated by an empty line ([vue/padding-line-between-blocks](https://eslint.vuejs.org/rules/padding-line-between-blocks.html))
* Function calls without arguments must not use parentheses: `v-on:click="something"` instead of `v-on:click="something()"` ([vue/v-on-function-call](https://eslint.vuejs.org/rules/v-on-function-call.html))
